==> kenga-0.0.51.tgz: package/events/value-change-event.js <==
'use strict';

var _classCallCheck = require('@babel/runtime/helpers/classCallCheck');
var _assertThisInitialized = require('@babel/runtime/helpers/assertThisInitialized');
var _inherits = require('@babel/runtime/helpers/inherits');
var _possibleConstructorReturn = require('@babel/runtime/helpers/possibleConstructorReturn');
var _getPrototypeOf = require('@babel/runtime/helpers/getPrototypeOf');
var event = require('../event.js');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var _classCallCheck__default = /*#__PURE__*/_interopDefaultLegacy(_classCallCheck);
var _assertThisInitialized__default = /*#__PURE__*/_interopDefaultLegacy(_assertThisInitialized);
var _inherits__default = /*#__PURE__*/_interopDefaultLegacy(_inherits);
var _possibleConstructorReturn__default = /*#__PURE__*/_interopDefaultLegacy(_possibleConstructorReturn);
var _getPrototypeOf__default = /*#__PURE__*/_interopDefaultLegacy(_getPrototypeOf);

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf__default['default'](Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf__default['default'](this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn__default['default'](this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

var ValueChangeEvent = /*#__PURE__*/function (_Event) {
  _inherits__default['default'](ValueChangeEvent, _Event);

  var _super = _createSuper(ValueChangeEvent);

  function ValueChangeEvent(w, oldValue, newValue) {
    var _this;

    _classCallCheck__default['default'](this, ValueChangeEvent);

    _this = _super.call(this, w, w);
    Object.defineProperty(_assertThisInitialized__default['default'](_this), 'newValue', {
      get: function get() {
        return newValue;
      }
    });
    Object.defineProperty(_assertThisInitialized__default['default'](_this), 'oldValue', {
      get: function get() {
        return oldValue;
      }
    });
    return _this;
  }

  return ValueChangeEvent;
}(event);

module.exports = ValueChangeEvent;

==> kenga-0.0.53.tgz: package/events/value-change-event.js <==
'use strict';

var _classCallCheck = require('@babel/runtime/helpers/classCallCheck');
var _assertThisInitialized = require('@babel/runtime/helpers/assertThisInitialized');
var _inherits = require('@babel/runtime/helpers/inherits');
var _possibleConstructorReturn = require('@babel/runtime/helpers/possibleConstructorReturn');
var _getPrototypeOf = require('@babel/runtime/helpers/getPrototypeOf');
var event = require('../event.js');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var _classCallCheck__default = /*#__PURE__*/_interopDefaultLegacy(_classCallCheck);
var _assertThisInitialized__default = /*#__PURE__*/_interopDefaultLegacy(_assertThisInitialized);
var _inherits__default = /*#__PURE__*/_interopDefaultLegacy(_inherits);
var _possibleConstructorReturn__default = /*#__PURE__*/_interopDefaultLegacy(_possibleConstructorReturn);
var _getPrototypeOf__default = /*#__PURE__*/_interopDefaultLegacy(_getPrototypeOf);

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf__default["default"](Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf__default["default"](this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn__default["default"](this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

var ValueChangeEvent = /*#__PURE__*/function (_Event) {
  _inherits__default["default"](ValueChangeEvent, _Event);

  var _super = _createSuper(ValueChangeEvent);

  function ValueChangeEvent(w, oldValue, newValue) {
    var _this;

    _classCallCheck__default["default"](this, ValueChangeEvent);

    _this = _super.call(this, w, w);
    Object.defineProperty(_assertThisInitialized__default["default"](_this), 'newValue', {
      get: function get() {
        return newValue;
      }
    });
    Object.defineProperty(_assertThisInitialized__default["default"](_this), 'oldValue', {
      get: function get() {
        return oldValue;
      }
    });
    return _this;
  }

  return ValueChangeEvent;
}(event);

module.exports = ValueChangeEvent;
